
/*

This class provides access to the Global object structures
that are common to all applets that are running visible portions
of the screens.  It is provided as a static variable among the frames.
All instantiations of this class share the common data.

*/

import java.applet.*;
import C2Message;
import java.util.Date;
import C2Applet;

public class C2MonObject    {

    public static boolean   isInitialized;      //  First guy in must initialize

    public static int       numberThreats;      //  Total known threats
    public static vector[] threatVectors;      //  Vectors for threats
    public static boolean[] threatsValid;       //  Vectors are valid


    public static int       numberDEFCONs;      //  Total known DEFCONs
    public static boolean[] DEFCONValid;       //  DEFCON is valid
    public static DEFCONState[] DEFCONStates;   //  List of DEFCON states

    public static int       numberBlueCraft;    //  Total Blue Aircraft
    public static vector[]  blueVectors;        //  Vectors for each Blue
    public static boolean[] blueValid;          //  Vector is valid

    public static int       AppletCount;

    public static final int maxThreatID = 10;
    public static final int maxBlueID = 10;
    public static final int maxNORADNodes = 10;

    public static final int maxCommands = 10;
    public static  int      ActualCommands = 0;

    public static final int IndexForCommands = 1;
    public static final int IndexForTracks = 2;
    public static final int IndexForTables = 3;

    public static C2Applet[] thePanelApplets;
    public static final int MaxPanelApplets = 10;
    public static boolean[] PanelAppletsDefined;


    public static String theParticipants[];
    public static int MaxParticipants;

    public static String theDirectives[];
    public static int MaxDirectives;

    public static final int NumberROCCs =  6;

    public int TrackChangeCounter;      //  The count of add/deletes to the track file
    public int NumberTracks;            //  Number of active track objects


    public C2MonObject  ()  {

        AppletCount = 0;

        if(AppletCount > 0)   {
            AppletCount++;
        }
        else    {
            numberThreats = 0;
            threatVectors = new vector [maxThreatID];
            threatsValid = new boolean [maxThreatID];
            for (int i = 0; i<maxThreatID; i++)
                threatsValid [i] = false;


            numberBlueCraft = 0;
            blueVectors = new vector [maxThreatID];
            blueValid = new boolean [maxThreatID];
            for (int i = 0; i<maxThreatID; i++)
                blueValid [i] = false;

            numberDEFCONs = C2Message.participantIsFirstROCC + NumberROCCs;
            DEFCONStates = new DEFCONState [numberDEFCONs];
            DEFCONValid = new boolean [numberDEFCONs];
            for (int i = 0; i<numberDEFCONs; i++)
                DEFCONValid [i] = false;


            AppletCount = 1;
            isInitialized =  true;

            thePanelApplets = new C2Applet[MaxPanelApplets];
            for (int i = 0; i<MaxPanelApplets; i++)

                 PanelAppletsDefined[i] = true;


            MaxParticipants = C2Message.participantIsFirstROCC + NumberROCCs;
            theParticipants = new String [MaxParticipants];

            theParticipants [C2Message.participantIsNotImportant] = "Player";
            theParticipants [C2Message.participantIsNORADCINC] = "CINC NORAD";
            theParticipants [C2Message.participantIsNORADADOC] = "NORAD ADOC";
            theParticipants [C2Message.participantIsUSPresident] = "NCA";
            theParticipants [C2Message.participantIsUSPilot] = "Pilot";
            theParticipants [C2Message.participantIsFEMA] =  "Dir FEMA";
            theParticipants [C2Message.participantIsLocalDoctor] =  "Medical Supp.";
            theParticipants [C2Message.participantIsDirector] = "Director";
            theParticipants [C2Message.participantIsAWACS] = "AWACS";
            theParticipants [C2Message.participantIsOther] =  "Other";
            theParticipants [C2Message.participantIsFirstROCC] =  "North East";
            theParticipants [C2Message.participantIsFirstROCC+1] =  "North West";
            theParticipants [C2Message.participantIsFirstROCC+2] =  "South East";
            theParticipants [C2Message.participantIsFirstROCC+3] =  "South West";
            theParticipants [C2Message.participantIsFirstROCC+4] =  "East Canada";
            theParticipants [C2Message.participantIsFirstROCC+5] =  "West Canada";

            MaxDirectives = 10;
            theDirectives = new String [MaxDirectives];

            theDirectives [0] = "Null Message";

            theDirectives [C2Message.MessageDEFCON1] = "Go To DEFCON 1";
            theDirectives [C2Message.MessageDEFCON2] = "Go To DEFCON 2";
            theDirectives [C2Message.MessageDEFCON3] = "Go To DEFCON 3";
            theDirectives [C2Message.MessageDEFCONIs1] = "Report DEFCON 1";
            theDirectives [C2Message.MessageDEFCONIs2] = "Report DEFCON 2";
            theDirectives [C2Message.MessageDEFCONIs3] =  "Report DEFCON 3";
            theDirectives [C2Message.MessageLaunchInterceptors] =  "Launch Interceptors";
            theDirectives [C2Message.MessagePerformIntercept] = "Perform Intercept";
            theDirectives [C2Message.MessageRecallInterceptors] =  "Recall Interceptors";



   //       Set up for track fine management
            TrackChangeCounter = 0;
            NumberTracks = 0;
        }
    }
    public int GetAppletCount ()    {
        return AppletCount;
    }

    public String   GetRoleName ()  {
        return theParticipants [GetRoleID()];
    }

   public byte   GetRoleID ()  {
        return C2Message.participantIsNORADCINC;
    }


    public void SetApplet (C2Applet theApplet, int theIndex)  {
        thePanelApplets [theIndex] = theApplet;
    }

    public void SendDirective   (byte DirectiveID)  {
       Date theDate = new Date();
       C2Message message = new C2Message (theDate,  false, GetRoleID(), C2Message.SendToAllPlayers);
       thePanelApplets[IndexForCommands].ReceiveCommand(message);

    }

    public String GetParticipantName (byte theParticipant)  {
        return theParticipants[theParticipant];
    }

    public int  GetDirectiveCount   ()  {
        return MaxDirectives;
    }

    public String GetDirectiveName (byte theDirective)  {
        return theDirectives[theDirective];
    }

    public int GetNumberROCCs ()    {
        return NumberROCCs;
    }
    public String GetROCCName (byte theROCC)  {
        return theParticipants[theROCC+ C2Message.participantIsFirstROCC];
    }

    public int GetTrackChangeCounter()  {
        return TrackChangeCounter;
    }

    public int GetThreatCount()  {
        return numberThreats;
    }

   public int GetTrackCount()  {
        return numberThreats + numberBlueCraft;
    }

    public vector GetTrack (int theIndex)  {
        return threatVectors[theIndex];
    }

    public void SendObject (byte theAppletIndex, C2Message theMessageObject)    {
        if (PanelAppletsDefined[theAppletIndex])    {
            thePanelApplets [theAppletIndex].receiveObject (theMessageObject);
        }
    }
}
